==========
superRAENN
==========

.. image:: https://img.shields.io/travis/villrv/superraenn.svg
        :target: https://travis-ci.org/villrv/superraenn

.. image:: https://img.shields.io/pypi/v/superraenn.svg
        :target: https://pypi.python.org/pypi/superraenn


Python package to classify  supernovae based on optical light curves

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://villrv.github.io/superraenn.

Features
--------

* TODO
